@@ -32,21 +32,18 @@
 #include <KIdentityManagement/kidentitymanagement/identity.h>
 
 #include <KLocalizedString>
-#include <KProcess>
-#include <QTemporaryFile>
 #include <KSharedConfig>
 #include <KConfigGroup>
 #include <KMessageBox>
 #include <KArchiveFile>
 #include <KZip>
-#include "pimsettingexportcore_debug.h"
+#include "pimdataexportcore_debug.h"
 
 #include <AkonadiCore/agenttype.h>
 #include <AkonadiCore/agentmanager.h>
 #include <AkonadiCore/agentinstancecreatejob.h>
 #include <AkonadiCore/CollectionFetchJob>
 
-
 #include <QMetaMethod>
 #include <QDir>
 #include <QStandardPaths>
@@ -101,7 +98,7 @@ void ImportMailJob::slotNextStep()
         } else if (type == Utils::Config) {
             restoreConfig();
         } else {
-            qCDebug(PIMSETTINGEXPORTERCORE_LOG) << Q_FUNC_INFO << " not supported type " << type;
+            qCDebug(PIMDATAEXPORTERCORE_LOG) << Q_FUNC_INFO << " not supported type " << type;
             slotNextStep();
         }
     } else {
@@ -155,7 +152,7 @@ void ImportMailJob::storeMailArchiveResource(const KArchiveDirectory *dir, const
                 files.debug();
                 mListResourceFile.append(files);
             } else {
-                qCDebug(PIMSETTINGEXPORTERCORE_LOG) << " Problem in archive. number of file " << lst.count();
+                qCDebug(PIMDATAEXPORTERCORE_LOG) << " Problem in archive. number of file " << lst.count();
             }
         }
     }
@@ -163,7 +160,7 @@ void ImportMailJob::storeMailArchiveResource(const KArchiveDirectory *dir, const
 
 void ImportMailJob::importMailTransport(const QString &tempDirName)
 {
-    KSharedConfig::Ptr transportConfig = KSharedConfig::openConfig(tempDirName + QLatin1Char('/') + QLatin1String("mailtransports"));
+    KSharedConfig::Ptr transportConfig = KSharedConfig::openConfig(tempDirName + QLatin1Char('/') + QStringLiteral("mailtransports"));
 
     int defaultTransport = -1;
     if (transportConfig->hasGroup(QStringLiteral("General"))) {
@@ -176,7 +173,7 @@ void ImportMailJob::importMailTransport(const QString &tempDirName)
         KConfigGroup group = transportConfig->group(transport);
         const int transportId = group.readEntry(QStringLiteral("id"), -1);
         if (transportId == -1) {
-            qCWarning(PIMSETTINGEXPORTERCORE_LOG) << "Mail Transport is incorrect. Missing Id";
+            qCWarning(PIMDATAEXPORTERCORE_LOG) << "Mail Transport is incorrect. Missing Id";
             continue;
         }
         const QString identifierStr(QStringLiteral("identifier"));
@@ -193,10 +190,10 @@ void ImportMailJob::importMailTransport(const QString &tempDirName)
                     mt->setIdentifier(identifierValue);
                     addMailTransport(mt, defaultTransport, transportId);
                 } else {
-                    qCWarning(PIMSETTINGEXPORTERCORE_LOG) << "Unknown identifier type " << identifierValue;
+                    qCWarning(PIMDATAEXPORTERCORE_LOG) << "Unknown identifier type " << identifierValue;
                 }
             } else {
-                qCWarning(PIMSETTINGEXPORTERCORE_LOG) << "identifier value is empty";
+                qCWarning(PIMDATAEXPORTERCORE_LOG) << "identifier value is empty";
             }
         } else {
             MailTransport::Transport *mt = MailTransport::TransportManager::self()->createTransport();
@@ -252,10 +249,10 @@ void ImportMailJob::importMailTransport(const QString &tempDirName)
                     } else if (encryptionType == QLatin1String("None")) {
                         mt->setEncryption(static_cast<int>(MailTransport::TransportBase::EnumEncryption::None));
                     } else {
-                        qCWarning(PIMSETTINGEXPORTERCORE_LOG) << "Unknown encryption type " << encryptionType;
+                        qCWarning(PIMDATAEXPORTERCORE_LOG) << "Unknown encryption type " << encryptionType;
                     }
                 } else {
-                    qCWarning(PIMSETTINGEXPORTERCORE_LOG) << "Encryption type is empty. It's a bug";
+                    qCWarning(PIMDATAEXPORTERCORE_LOG) << "Encryption type is empty. It's a bug";
                 }
                 mt->setEncryption(group.readEntry(encryptionStr, 1)); //TODO verify
             }
@@ -266,14 +263,13 @@ void ImportMailJob::importMailTransport(const QString &tempDirName)
             addMailTransport(mt, defaultTransport, transportId);
         }
     }
-
 }
 
 void ImportMailJob::restoreTransports()
 {
     setProgressDialogLabel(i18n("Restore transports..."));
     increaseProgressDialog();
-    const QString path = Utils::transportsPath() + QLatin1String("mailtransports");
+    const QString path = Utils::transportsPath() + QStringLiteral("mailtransports");
     if (!mFileList.contains(path)) {
         Q_EMIT error(i18n("mailtransports file could not be found in the archive."));
     } else {
@@ -283,7 +279,7 @@ void ImportMailJob::restoreTransports()
         if (transport && transport->isFile()) {
             const KArchiveFile *fileTransport = static_cast<const KArchiveFile *>(transport);
 
-            fileTransport->copyTo(mTempDirName);
+            copyArchiveFileTo(fileTransport, mTempDirName);
             importMailTransport(mTempDirName);
             Q_EMIT info(i18n("Transports restored."));
         } else {
@@ -323,7 +319,7 @@ void ImportMailJob::restoreResources()
                 if (agentFileConfigEntry && agentFileConfigEntry->isFile()) {
                     const KArchiveFile *file = static_cast<const KArchiveFile *>(agentFileConfigEntry);
                     const QString destDirectory = mTempDirName + QLatin1Char('/') + Utils::resourcesPath();
-                    file->copyTo(destDirectory);
+                    copyArchiveFileTo(file, destDirectory);
                     const QString filename(file->name());
                     const QString agentResourceFileName = destDirectory + QLatin1Char('/') + filename;
                     resourceName = Utils::akonadiAgentName(agentResourceFileName);
@@ -334,7 +330,7 @@ void ImportMailJob::restoreResources()
                 const KArchiveFile *file = static_cast<const KArchiveFile *>(fileEntry);
                 const QString destDirectory = mTempDirName + QLatin1Char('/') + Utils::resourcesPath();
 
-                file->copyTo(destDirectory);
+                copyArchiveFileTo(file, destDirectory);
 
                 const QString filename(file->name());
                 const QString resourceFileName = destDirectory + QLatin1Char('/') + filename;
@@ -477,7 +473,7 @@ void ImportMailJob::restoreResources()
                         if (collection != -1) {
                             settings.insert(QStringLiteral("TrashCollection"), collection);
                         } else {
-                            qCDebug(PIMSETTINGEXPORTERCORE_LOG) << " Use default trash folder";
+                            qCDebug(PIMDATAEXPORTERCORE_LOG) << " Use default trash folder";
                         }
                     }
 
@@ -521,7 +517,7 @@ void ImportMailJob::restoreResources()
                         infoAboutNewResource(newResource);
                     }
                 } else {
-                    qCDebug(PIMSETTINGEXPORTERCORE_LOG) << " problem with resource";
+                    qCWarning(PIMDATAEXPORTERCORE_LOG) << " problem with resource: " << filename;
                 }
             }
         }
@@ -550,10 +546,10 @@ void ImportMailJob::restoreMails()
         const KArchiveEntry *fileResouceEntry = mArchiveDirectory->entry(resourceFile);
         if (fileResouceEntry && fileResouceEntry->isFile()) {
             const KArchiveFile *file = static_cast<const KArchiveFile *>(fileResouceEntry);
-            file->copyTo(copyToDirName);
+            copyArchiveFileTo(file, copyToDirName);
             QString resourceName(file->name());
             QString filename(file->name());
-            //qCDebug(PIMSETTINGEXPORTERCORE_LOG)<<" filename "<<filename<<" resourceName"<<resourceName;
+            //qCDebug(PIMDATAEXPORTERCORE_LOG)<<" filename "<<filename<<" resourceName"<<resourceName;
             KSharedConfig::Ptr resourceConfig = KSharedConfig::openConfig(copyToDirName + QLatin1Char('/') + resourceName);
 
             const QString newUrl = Utils::adaptResourcePath(resourceConfig, storeMails());
@@ -563,7 +559,7 @@ void ImportMailJob::restoreMails()
                 const KArchiveEntry *akonadiAgentConfigEntry = mArchiveDirectory->entry(agentConfigFile);
                 if (akonadiAgentConfigEntry->isFile()) {
                     const KArchiveFile *file = static_cast<const KArchiveFile *>(akonadiAgentConfigEntry);
-                    file->copyTo(copyToDirName);
+                    copyArchiveFileTo(file, copyToDirName);
                     resourceName = file->name();
                     filename = Utils::akonadiAgentName(copyToDirName + QLatin1Char('/') + resourceName);
                 }
@@ -575,7 +571,7 @@ void ImportMailJob::restoreMails()
                 const KArchiveEntry *dataResouceEntry = mArchiveDirectory->entry(dataFile);
                 if (dataResouceEntry->isFile()) {
                     const KArchiveFile *file = static_cast<const KArchiveFile *>(dataResouceEntry);
-                    file->copyTo(newUrl);
+                    copyArchiveFileTo(file, newUrl);
                 }
                 settings.insert(QStringLiteral("Path"), newUrl);
 
@@ -645,9 +641,9 @@ void ImportMailJob::restoreMails()
                 }
                 listResourceToSync << newResource;
             } else {
-                qCDebug(PIMSETTINGEXPORTERCORE_LOG) << " resource name not supported " << resourceName;
+                qCDebug(PIMDATAEXPORTERCORE_LOG) << " resource name not supported " << resourceName;
             }
-            //qCDebug(PIMSETTINGEXPORTERCORE_LOG)<<"url "<<url;
+            //qCDebug(PIMDATAEXPORTERCORE_LOG)<<"url "<<url;
         }
     }
     Q_EMIT info(i18n("Mails restored."));
@@ -658,7 +654,7 @@ void ImportMailJob::restoreConfig()
 {
     increaseProgressDialog();
     setProgressDialogLabel(i18n("Restore config..."));
-    const QString filtersPath(Utils::configsPath() + QLatin1String("filters"));
+    const QString filtersPath(Utils::configsPath() + QStringLiteral("filters"));
     if (!mFileList.contains(filtersPath)) {
         Q_EMIT error(i18n("filters file could not be found in the archive."));
     } else {
@@ -666,8 +662,8 @@ void ImportMailJob::restoreConfig()
         if (filter && filter->isFile()) {
             const KArchiveFile *fileFilter = static_cast<const KArchiveFile *>(filter);
 
-            fileFilter->copyTo(mTempDirName);
-            const QString filterFileName(mTempDirName + QLatin1Char('/') + QLatin1String("filters"));
+            copyArchiveFileTo(fileFilter, mTempDirName);
+            const QString filterFileName(mTempDirName + QLatin1Char('/') + QStringLiteral("filters"));
             KSharedConfig::Ptr filtersConfig = KSharedConfig::openConfig(filterFileName);
             const QStringList filterList = filtersConfig->groupList().filter(QRegularExpression(QStringLiteral("Filter #\\d+")));
             for (const QString &filterStr : filterList) {
@@ -716,7 +712,7 @@ void ImportMailJob::restoreConfig()
 
             bool canceled = false;
             MailCommon::FilterImporterExporter exportFilters;
-            QList<MailCommon::MailFilter *> lstFilter = exportFilters.importFilters(canceled, MailCommon::FilterImporterExporter::KMailFilter, filterFileName);
+            QVector<MailCommon::MailFilter *> lstFilter = exportFilters.importFilters(canceled, MailCommon::FilterImporterExporter::KMailFilter, filterFileName);
             if (canceled) {
                 MailCommon::FilterManager::instance()->appendFilters(lstFilter);
             }
@@ -894,18 +890,18 @@ void ImportMailJob::restoreConfig()
 
     importSimpleFilesInDirectory(QStringLiteral("/autocorrect/"));
     importSimpleFilesInDirectory(QStringLiteral("/gravatar/"));
-    const KArchiveEntry *kmail2Entry = mArchiveDirectory->entry(Utils::dataPath() + QLatin1String("kmail2/adblockrules_local"));
+    const KArchiveEntry *kmail2Entry = mArchiveDirectory->entry(Utils::dataPath() + QStringLiteral("kmail2/adblockrules_local"));
     if (kmail2Entry && kmail2Entry->isFile()) {
         const KArchiveFile *entry = static_cast<const KArchiveFile *>(kmail2Entry);
-        const QString adblockPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + QLatin1String("kmail2/adblockrules_local");
+        const QString adblockPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + QStringLiteral("kmail2/adblockrules_local");
         if (QFileInfo::exists(adblockPath)) {
             if (overwriteConfigMessageBox(QStringLiteral("adblockrules_local"))) {
-                copyToFile(entry, QString(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/") + QLatin1String("kmail2/adblockrules_local")),
-                           QStringLiteral("adblockrules_local"), Utils::dataPath() + QLatin1String("kmail2/"));
+                copyToFile(entry, QString(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/") + QStringLiteral("kmail2/adblockrules_local")),
+                           QStringLiteral("adblockrules_local"), Utils::dataPath() + QStringLiteral("kmail2/"));
             }
         } else {
-            copyToFile(entry, QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + QLatin1String("kmail2/adblockrules_local"), QStringLiteral(
-                           "adblockrules_local"), Utils::dataPath() + QLatin1String("kmail2/"));
+            copyToFile(entry, QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + QStringLiteral("kmail2/adblockrules_local"), QStringLiteral(
+                           "adblockrules_local"), Utils::dataPath() + QStringLiteral("kmail2/"));
         }
     }
 
@@ -945,20 +941,19 @@ void ImportMailJob::registerSpecialCollection(Akonadi::SpecialMailCollections::T
 {
     auto fetch = new Akonadi::CollectionFetchJob(Akonadi::Collection(colId), Akonadi::CollectionFetchJob::Base, this);
     connect(fetch, &Akonadi::CollectionFetchJob::collectionsReceived,
-            this, [this, type](const Akonadi::Collection::List &cols) {
-                if (cols.count() != 1) {
-                    return;
-                }
-                Akonadi::SpecialMailCollections::self()->registerCollection(type, cols.first());
-            });
+            this, [ type](const Akonadi::Collection::List &cols) {
+        if (cols.count() != 1) {
+            return;
+        }
+        Akonadi::SpecialMailCollections::self()->registerCollection(type, cols.first());
+    });
 }
 
-
 void ImportMailJob::restoreIdentity()
 {
     increaseProgressDialog();
     setProgressDialogLabel(i18n("Restoring identities..."));
-    const QString path(Utils::identitiesPath() + QLatin1String("emailidentities"));
+    const QString path(Utils::identitiesPath() + QStringLiteral("emailidentities"));
     if (!mFileList.contains(path)) {
         Q_EMIT error(i18n("emailidentities file could not be found in the archive."));
     } else {
@@ -967,8 +962,8 @@ void ImportMailJob::restoreIdentity()
         const KArchiveEntry *identity = mArchiveDirectory->entry(path);
         if (identity && identity->isFile()) {
             const KArchiveFile *fileIdentity = static_cast<const KArchiveFile *>(identity);
-            fileIdentity->copyTo(mTempDirName);
-            KSharedConfig::Ptr identityConfig = KSharedConfig::openConfig(mTempDirName + QLatin1Char('/') + QLatin1String("emailidentities"));
+            copyArchiveFileTo(fileIdentity, mTempDirName);
+            KSharedConfig::Ptr identityConfig = KSharedConfig::openConfig(mTempDirName + QLatin1Char('/') + QStringLiteral("emailidentities"));
             KConfigGroup general = identityConfig->group(QStringLiteral("General"));
             const int defaultIdentity = general.readEntry(QStringLiteral("Default Identity"), -1);
 
@@ -1010,7 +1005,7 @@ void ImportMailJob::restoreIdentity()
                                         fileInfo.fileName());
                                     ++i;
                                 }
-                                vcardFile->copyTo(QFileInfo(vcardFilePath).absolutePath());
+                                copyArchiveFileTo(vcardFile, QFileInfo(vcardFilePath).absolutePath());
                                 group.writeEntry(vcard, vcardFilePath);
                             }
                         }
@@ -1056,6 +1051,7 @@ void ImportMailJob::importArchiveConfig(const KArchiveFile *archiveconfiguration
     copyToFile(archiveconfiguration, archiveconfigurationrc, filename, prefix);
     KSharedConfig::Ptr archiveConfig = KSharedConfig::openConfig(archiveconfigurationrc);
 
+    //TODO fix FolderArchiveAccount
     copyArchiveMailAgentConfigGroup(archiveConfig, archiveConfig);
     archiveConfig->sync();
 }
@@ -1145,13 +1141,6 @@ void ImportMailJob::importKmailConfig(const KArchiveFile *kmailsnippet, const QS
     copyToFile(kmailsnippet, kmail2rc, filename, prefix);
     KSharedConfig::Ptr kmailConfig = KSharedConfig::openConfig(kmail2rc);
 
-    //Be sure to delete Search group
-    const QString search(QStringLiteral("Search"));
-    if (kmailConfig->hasGroup(search)) {
-        KConfigGroup searchGroup = kmailConfig->group(search);
-        searchGroup.deleteGroup();
-    }
-
     //adapt folder id
     const QString folderGroupPattern = QStringLiteral("Folder-");
     const QStringList folderList = kmailConfig->groupList().filter(folderGroupPattern);
@@ -1215,23 +1204,10 @@ void ImportMailJob::importKmailConfig(const KArchiveFile *kmailsnippet, const QS
         convertRealPathToCollectionList(favoriteGroup, expensionKey);
     }
 
+    convertCollectionListStrToAkonadiId(kmailConfig, QStringLiteral("FavoriteCollections"), QStringLiteral("FavoriteCollectionIds"), false);
 
-    const QString favoriteCollectionStr(QStringLiteral("FavoriteCollections"));
-    if (kmailConfig->hasGroup(favoriteCollectionStr)) {
-        KConfigGroup favoriteGroup = kmailConfig->group(favoriteCollectionStr);
-
-        const QString favoriteCollectionIdsStr(QStringLiteral("FavoriteCollectionIds"));
-        convertRealPathToCollectionList(favoriteGroup, favoriteCollectionIdsStr, false);
-    }
-
-    const QString favoriteCollectionOrderStr(QStringLiteral("FavoriteCollectionsOrder"));
-    if (kmailConfig->hasGroup(favoriteCollectionOrderStr)) {
-        KConfigGroup favoriteGroupOrder = kmailConfig->group(favoriteCollectionOrderStr);
-
-        //For favorite id for root collection == 0 and we store only folder => c
-        const QString favoriteCollectionOrderIdsStr(QStringLiteral("0"));
-        convertRealPathToCollectionList(favoriteGroupOrder, favoriteCollectionOrderIdsStr, true);
-    }
+    //For favorite id for root collection == 0 and we store only folder => c
+    convertCollectionListStrToAkonadiId(kmailConfig, QStringLiteral("FavoriteCollectionsOrder"), QStringLiteral("0"), true);
 
     //Event collection
     convertCollectionStrToAkonadiId(kmailConfig, QStringLiteral("Event"), QStringLiteral("LastEventSelectedFolder"));
@@ -1241,13 +1217,7 @@ void ImportMailJob::importKmailConfig(const KArchiveFile *kmailsnippet, const QS
     convertCollectionStrToAkonadiId(kmailConfig, QStringLiteral("Note"), QStringLiteral("LastNoteSelectedFolder"));
 
     //FolderSelectionDialog collection
-    const QString folderSelectionCollectionStr(QStringLiteral("FolderSelectionDialog"));
-    if (kmailConfig->hasGroup(folderSelectionCollectionStr)) {
-        KConfigGroup folderSelectionGroup = kmailConfig->group(folderSelectionCollectionStr);
-        const QString folderSelectionSelectedFolder(QStringLiteral("LastSelectedFolder"));
-        convertRealPathToCollectionList(folderSelectionGroup, folderSelectionSelectedFolder, false);
-    }
-
+    convertCollectionListStrToAkonadiId(kmailConfig, QStringLiteral("FolderSelectionDialog"), QStringLiteral("LastSelectedFolder"), false);
 
     //Convert MessageListTab collection id
     const QString messageListPaneStr(QStringLiteral("MessageListPane"));
@@ -1261,7 +1231,6 @@ void ImportMailJob::importKmailConfig(const KArchiveFile *kmailsnippet, const QS
         }
     }
 
-
     //Automatic Add Contacts
     QHash<int, uint>::const_iterator i = mHashIdentity.constBegin();
     while (i != mHashIdentity.constEnd()) {
@@ -1315,7 +1284,7 @@ void ImportMailJob::mergeLdapConfig(const KArchiveFile *archivefile, const QStri
     dir.mkdir(prefix);
 
     const QString copyToDirName(mTempDirName + QLatin1Char('/') + prefix);
-    archivefile->copyTo(copyToDirName);
+    copyArchiveFileTo(archivefile, copyToDirName);
 
     KSharedConfig::Ptr existingConfig = KSharedConfig::openConfig(filename);
     KConfigGroup grpExisting = existingConfig->group(QStringLiteral("LDAP"));
@@ -1377,7 +1346,7 @@ void ImportMailJob::mergeKmailSnippetConfig(const KArchiveFile *archivefile, con
     dir.mkdir(prefix);
 
     const QString copyToDirName(mTempDirName + QLatin1Char('/') + prefix);
-    archivefile->copyTo(copyToDirName);
+    copyArchiveFileTo(archivefile, copyToDirName);
 
     KSharedConfig::Ptr existingConfig = KSharedConfig::openConfig(filename);
 
@@ -1406,7 +1375,7 @@ void ImportMailJob::mergeSieveTemplate(const KArchiveFile *archivefile, const QS
     dir.mkdir(prefix);
 
     const QString copyToDirName(mTempDirName + QLatin1Char('/') + prefix);
-    archivefile->copyTo(copyToDirName);
+    copyArchiveFileTo(archivefile, copyToDirName);
 
     KSharedConfig::Ptr existingConfig = KSharedConfig::openConfig(filename);
 
