@@ -25,7 +25,8 @@ class QTreeWidget;
 class QTreeWidgetItem;
 class KArchiveEntry;
 class KArchiveDirectory;
-
+class QPushButton;
+class KZip;
 class ShowArchiveStructureDialog : public QDialog
 {
     Q_OBJECT
@@ -33,20 +34,28 @@ public:
     explicit ShowArchiveStructureDialog(const QString &filename, QWidget *parent = nullptr);
     ~ShowArchiveStructureDialog();
 
+    enum File {
+        FullPath = Qt::UserRole + 1
+    };
+
 private:
     void slotExportAsLogFile();
     void exportAsLogFile();
     bool fillTree();
     void readConfig();
     void writeConfig();
+    void slotItemClicked(QTreeWidgetItem *item, int column);
+    void addSubItems(const QString &topLevelPath, QTreeWidgetItem *parent, const KArchiveEntry *entry, int indent, const QString &fullpath = QString());
+    void slotExtractFile();
 
     bool searchArchiveElement(const QString &path, const KArchiveDirectory *topDirectory, const QString &name);
     QTreeWidgetItem *addTopItem(const QString &name);
-    void addSubItems(QTreeWidgetItem *parent, const KArchiveEntry *entry, int indent);
-    QTreeWidgetItem *addItem(QTreeWidgetItem *parent, const QString &name);
+    QTreeWidgetItem *addItem(QTreeWidgetItem *parent, const QString &name, const QString &fillFullPath);
     QString mFileName;
     QString mLogFile;
     QTreeWidget *mTreeWidget = nullptr;
+    QPushButton *mExtractFile = nullptr;
+    KZip *mZip = nullptr;
 };
 
 #endif // SHOWARCHIVESTRUCTUREDIALOG_H
